<?php
namespace Teknisa\PED\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Geral\Logic\ParceiroNegocio;
use Teknisa\PED\Controllers\TeknisaCrud;
use Teknisa\PED\Services\Ger00700ClienteService;
use Zeedhi\Framework\DataSource\DataSet;

class Ger00700ClienteController extends TeknisaCrud
{
    protected $dataSourceName;

    public function __construct($crudService, $parameterBag, Ger00700ClienteService $service) {
        $this->service    = $service;
        parent::__construct($crudService, $parameterBag);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()));
        $this->dataSourceName = $dataSource;
        parent::find($request, $response);
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 6);
        $this->dataSourceName = $dataSource;
        parent::save($request, $response);
    }

    public function delete(DTO\Request $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()) - 8);
        $this->dataSourceName = $dataSource;
        parent::delete($request, $response);
    }

    public function deleteFormaPagamento(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->service->deleteFormaPagamento($request->getRow());
        }
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 500));
        }
    }
    
    public function salvarObservacaoCliente(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = 'observclie_operador';
        $row = $request->getRow();
        $row['DSOBSERVCLIE'] = isset($row['DSOBSERVCLIE'])?bin2hex($row['DSOBSERVCLIE']):null;
        parent::save($request, $response);
    }
    /*
        Faz a busca em todas as observações por cliente.
        Caso o campo não se eocntre no formato html, realiza a
        conversão do campo de RTF (Formato que é utilizado no Delphi) para
        HTML (Formato entendido pelo mobile)
    */
    public function findObservacaoCliente(DTO\Request $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()));
        $this->dataSourceName = $dataSource;
        parent::find($request, $response);
        
        $rows  = $response->getDataSets()[0]->getRows();
        $rows  = $this->service->rtf2Html($rows);
        
        $dataSet = new DataSet("observclie_operador", $rows);
        $response->setDataSets(array($dataSet));
    }
    
    public function checkPendencias(DTO\Request $request,  DTO\Response $response) {
        
        $params = $request->getParameter('dataset');
        
        $dataSet = new DataSet("pendencia_cliente", $this->service->checkPendencias($params)); 
        
        $response->setDataSets(array($dataSet));
        
        return $response;
        
    }
    
}